# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/problem_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import code_template_pb2 as eolymp_dot_atlas_dot_code__template__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import submission_pb2 as eolymp_dot_atlas_dot_submission__pb2
from eolymp.atlas import testing_test_pb2 as eolymp_dot_atlas_dot_testing__test__pb2
from eolymp.playground import run_pb2 as eolymp_dot_playground_dot_run__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/course/problem_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/atlas/code_template.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a\x1d\x65olymp/atlas/submission.proto\x1a\x1f\x65olymp/atlas/testing_test.proto\x1a\x1b\x65olymp/playground/run.proto\x1a!eolymp/wellknown/expression.proto\"\x15\n\x13ListStatementsInput\"M\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.atlas.Statement\"\x13\n\x11ListExamplesInput\":\n\x12ListExamplesOutput\x12$\n\x08\x65xamples\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"L\n\x15\x43reateSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\x97\x04\n\x14ListSubmissionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.course.ListSubmissionsInput.Filter\x1a\xa3\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\t \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12;\n\x0csubmitted_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x31\n\x07runtime\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x08 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\"O\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Submission\"D\n\x17\x44\x65scribeSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"H\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\"A\n\x14WatchSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"E\n\x15WatchSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\"*\n\x17LookupCodeTemplateInput\x12\x0f\n\x07runtime\x18\x01 \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\"e\n\x0e\x43reateRunInput\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x64 \x01(\t\x12\x14\n\ninput_data\x18\x65 \x01(\x0cH\x00\x12\x13\n\tinput_ref\x18\x66 \x01(\tH\x00\x42\x07\n\x05input\"!\n\x0f\x43reateRunOutput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\"\n\x10\x44\x65scribeRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"8\n\x11\x44\x65scribeRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run\"\x1f\n\rWatchRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"5\n\x0eWatchRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run2\x84\x0c\n\x0eProblemService\x12\x97\x01\n\x0eListStatements\x12\".eolymp.course.ListStatementsInput\x1a#.eolymp.course.ListStatementsOutput\"<\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\r\x12\x0b/statements\x12\x8f\x01\n\x0cListExamples\x12 .eolymp.course.ListExamplesInput\x1a!.eolymp.course.ListExamplesOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/examples\x12\xa0\x01\n\x10\x43reateSubmission\x12$.eolymp.course.CreateSubmissionInput\x1a%.eolymp.course.CreateSubmissionOutput\"?\x82\xe3\n\x18\x8a\xe3\n\x14\x63ourse:course:submit\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0e\"\x0c/submissions\x12\x9b\x01\n\x0fListSubmissions\x12#.eolymp.course.ListSubmissionsInput\x1a$.eolymp.course.ListSubmissionsOutput\"=\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xb4\x01\n\x12\x44\x65scribeSubmission\x12&.eolymp.course.DescribeSubmissionInput\x1a\'.eolymp.course.DescribeSubmissionOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12z\n\x0fWatchSubmission\x12#.eolymp.course.WatchSubmissionInput\x1a$.eolymp.course.WatchSubmissionOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read0\x01\x12\xa1\x01\n\x12LookupCodeTemplate\x12&.eolymp.course.LookupCodeTemplateInput\x1a\'.eolymp.course.LookupCodeTemplateOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0b\x12\t/template\x12\x84\x01\n\tCreateRun\x12\x1d.eolymp.course.CreateRunInput\x1a\x1e.eolymp.course.CreateRunOutput\"8\x82\xe3\n\x18\x8a\xe3\n\x14playground:run:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/runs\x12\x92\x01\n\x0b\x44\x65scribeRun\x12\x1f.eolymp.course.DescribeRunInput\x1a .eolymp.course.DescribeRunOutput\"@\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10\x12\x0e/runs/{run_id}\x12\x91\x01\n\x08WatchRun\x12\x1c.eolymp.course.WatchRunInput\x1a\x1d.eolymp.course.WatchRunOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x16\x12\x14/runs/{run_id}/watch0\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.problem_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _PROBLEMSERVICE.methods_by_name['ListStatements']._options = None
  _PROBLEMSERVICE.methods_by_name['ListStatements']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\r\022\013/statements'
  _PROBLEMSERVICE.methods_by_name['ListExamples']._options = None
  _PROBLEMSERVICE.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/examples'
  _PROBLEMSERVICE.methods_by_name['CreateSubmission']._options = None
  _PROBLEMSERVICE.methods_by_name['CreateSubmission']._serialized_options = b'\202\343\n\030\212\343\n\024course:course:submit\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\323\344\223\002\016\"\014/submissions'
  _PROBLEMSERVICE.methods_by_name['ListSubmissions']._options = None
  _PROBLEMSERVICE.methods_by_name['ListSubmissions']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\022\014/submissions'
  _PROBLEMSERVICE.methods_by_name['DescribeSubmission']._options = None
  _PROBLEMSERVICE.methods_by_name['DescribeSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _PROBLEMSERVICE.methods_by_name['WatchSubmission']._options = None
  _PROBLEMSERVICE.methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read'
  _PROBLEMSERVICE.methods_by_name['LookupCodeTemplate']._options = None
  _PROBLEMSERVICE.methods_by_name['LookupCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\013\022\t/template'
  _PROBLEMSERVICE.methods_by_name['CreateRun']._options = None
  _PROBLEMSERVICE.methods_by_name['CreateRun']._serialized_options = b'\202\343\n\030\212\343\n\024playground:run:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\007\"\005/runs'
  _PROBLEMSERVICE.methods_by_name['DescribeRun']._options = None
  _PROBLEMSERVICE.methods_by_name['DescribeRun']._serialized_options = b'\202\343\n\027\212\343\n\023playground:run:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\020\022\016/runs/{run_id}'
  _PROBLEMSERVICE.methods_by_name['WatchRun']._options = None
  _PROBLEMSERVICE.methods_by_name['WatchRun']._serialized_options = b'\202\343\n\027\212\343\n\023playground:run:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\026\022\024/runs/{run_id}/watch'
  _LISTSTATEMENTSINPUT._serialized_start=345
  _LISTSTATEMENTSINPUT._serialized_end=366
  _LISTSTATEMENTSOUTPUT._serialized_start=368
  _LISTSTATEMENTSOUTPUT._serialized_end=445
  _LISTEXAMPLESINPUT._serialized_start=447
  _LISTEXAMPLESINPUT._serialized_end=466
  _LISTEXAMPLESOUTPUT._serialized_start=468
  _LISTEXAMPLESOUTPUT._serialized_end=526
  _CREATESUBMISSIONINPUT._serialized_start=528
  _CREATESUBMISSIONINPUT._serialized_end=604
  _CREATESUBMISSIONOUTPUT._serialized_start=606
  _CREATESUBMISSIONOUTPUT._serialized_end=653
  _LISTSUBMISSIONSINPUT._serialized_start=656
  _LISTSUBMISSIONSINPUT._serialized_end=1191
  _LISTSUBMISSIONSINPUT_FILTER._serialized_start=772
  _LISTSUBMISSIONSINPUT_FILTER._serialized_end=1191
  _LISTSUBMISSIONSOUTPUT._serialized_start=1193
  _LISTSUBMISSIONSOUTPUT._serialized_end=1272
  _DESCRIBESUBMISSIONINPUT._serialized_start=1274
  _DESCRIBESUBMISSIONINPUT._serialized_end=1342
  _DESCRIBESUBMISSIONOUTPUT._serialized_start=1344
  _DESCRIBESUBMISSIONOUTPUT._serialized_end=1416
  _WATCHSUBMISSIONINPUT._serialized_start=1418
  _WATCHSUBMISSIONINPUT._serialized_end=1483
  _WATCHSUBMISSIONOUTPUT._serialized_start=1485
  _WATCHSUBMISSIONOUTPUT._serialized_end=1554
  _LOOKUPCODETEMPLATEINPUT._serialized_start=1556
  _LOOKUPCODETEMPLATEINPUT._serialized_end=1598
  _LOOKUPCODETEMPLATEOUTPUT._serialized_start=1600
  _LOOKUPCODETEMPLATEOUTPUT._serialized_end=1668
  _CREATERUNINPUT._serialized_start=1670
  _CREATERUNINPUT._serialized_end=1771
  _CREATERUNOUTPUT._serialized_start=1773
  _CREATERUNOUTPUT._serialized_end=1806
  _DESCRIBERUNINPUT._serialized_start=1808
  _DESCRIBERUNINPUT._serialized_end=1842
  _DESCRIBERUNOUTPUT._serialized_start=1844
  _DESCRIBERUNOUTPUT._serialized_end=1900
  _WATCHRUNINPUT._serialized_start=1902
  _WATCHRUNINPUT._serialized_end=1933
  _WATCHRUNOUTPUT._serialized_start=1935
  _WATCHRUNOUTPUT._serialized_end=1988
  _PROBLEMSERVICE._serialized_start=1991
  _PROBLEMSERVICE._serialized_end=3531
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import assignment_pb2 as _assignment_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAssignmentInput(_message.Message):
    __slots__ = ["assignment"]
    ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    assignment: _assignment_pb2.Assignment
    def __init__(self, assignment: _Optional[_Union[_assignment_pb2.Assignment, _Mapping]] = ...) -> None: ...

class CreateAssignmentOutput(_message.Message):
    __slots__ = ["assignment_id"]
    ASSIGNMENT_ID_FIELD_NUMBER: _ClassVar[int]
    assignment_id: str
    def __init__(self, assignment_id: _Optional[str] = ...) -> None: ...

class DeleteAssignmentInput(_message.Message):
    __slots__ = ["assignment_id"]
    ASSIGNMENT_ID_FIELD_NUMBER: _ClassVar[int]
    assignment_id: str
    def __init__(self, assignment_id: _Optional[str] = ...) -> None: ...

class DeleteAssignmentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeAssignmentInput(_message.Message):
    __slots__ = ["assignment_id", "extra"]
    ASSIGNMENT_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    assignment_id: str
    extra: _containers.RepeatedScalarFieldContainer[_assignment_pb2.Assignment.Extra]
    def __init__(self, assignment_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_assignment_pb2.Assignment.Extra, str]]] = ...) -> None: ...

class DescribeAssignmentOutput(_message.Message):
    __slots__ = ["assignment"]
    ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    assignment: _assignment_pb2.Assignment
    def __init__(self, assignment: _Optional[_Union[_assignment_pb2.Assignment, _Mapping]] = ...) -> None: ...

class IntrospectAssignmentInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectAssignmentOutput(_message.Message):
    __slots__ = ["assignment"]
    ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    assignment: _assignment_pb2.Assignment
    def __init__(self, assignment: _Optional[_Union[_assignment_pb2.Assignment, _Mapping]] = ...) -> None: ...

class ListAssignmentsInput(_message.Message):
    __slots__ = ["extra", "filters", "offset", "order", "size", "sort"]
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["group_id", "id", "member_id"]
        GROUP_ID_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        group_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., group_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    DEFAULT: ListAssignmentsInput.Sortable
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_assignment_pb2.Assignment.Extra]
    filters: ListAssignmentsInput.Filter
    offset: int
    order: _direction_pb2.Direction
    size: int
    sort: ListAssignmentsInput.Sortable
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListAssignmentsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListAssignmentsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_assignment_pb2.Assignment.Extra, str]]] = ...) -> None: ...

class ListAssignmentsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_assignment_pb2.Assignment]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_assignment_pb2.Assignment, _Mapping]]] = ...) -> None: ...

class StartAssignmentInput(_message.Message):
    __slots__ = ["entry_id"]
    ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    entry_id: str
    def __init__(self, entry_id: _Optional[str] = ...) -> None: ...

class StartAssignmentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateAssignmentInput(_message.Message):
    __slots__ = ["assignment", "assignment_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateAssignmentInput.Patch
    ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    ASSIGNMENT_ID_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_BEFORE: UpdateAssignmentInput.Patch
    DURATION: UpdateAssignmentInput.Patch
    ITEMS: UpdateAssignmentInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    START_AFTER: UpdateAssignmentInput.Patch
    assignment: _assignment_pb2.Assignment
    assignment_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateAssignmentInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateAssignmentInput.Patch, str]]] = ..., assignment_id: _Optional[str] = ..., assignment: _Optional[_Union[_assignment_pb2.Assignment, _Mapping]] = ...) -> None: ...

class UpdateAssignmentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import testing_config_pb2 as _testing_config_pb2
from eolymp.atlas import testing_test_pb2 as _testing_test_pb2
from eolymp.atlas import testing_testset_pb2 as _testing_testset_pb2
from eolymp.executor import checker_pb2 as _checker_pb2
from eolymp.executor import interactor_pb2 as _interactor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateTestInput(_message.Message):
    __slots__ = ["problem_id", "test", "testset_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    TEST_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    test: _testing_test_pb2.Test
    testset_id: str
    def __init__(self, problem_id: _Optional[str] = ..., testset_id: _Optional[str] = ..., test: _Optional[_Union[_testing_test_pb2.Test, _Mapping]] = ...) -> None: ...

class CreateTestOutput(_message.Message):
    __slots__ = ["test_id"]
    TEST_ID_FIELD_NUMBER: _ClassVar[int]
    test_id: str
    def __init__(self, test_id: _Optional[str] = ...) -> None: ...

class CreateTestsetInput(_message.Message):
    __slots__ = ["problem_id", "testset"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    testset: _testing_testset_pb2.Testset
    def __init__(self, problem_id: _Optional[str] = ..., testset: _Optional[_Union[_testing_testset_pb2.Testset, _Mapping]] = ...) -> None: ...

class CreateTestsetOutput(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteTestInput(_message.Message):
    __slots__ = ["problem_id", "test_id", "testset_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    TEST_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    test_id: str
    testset_id: str
    def __init__(self, problem_id: _Optional[str] = ..., testset_id: _Optional[str] = ..., test_id: _Optional[str] = ...) -> None: ...

class DeleteTestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteTestsetInput(_message.Message):
    __slots__ = ["problem_id", "testset_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    testset_id: str
    def __init__(self, problem_id: _Optional[str] = ..., testset_id: _Optional[str] = ...) -> None: ...

class DeleteTestsetOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeCheckerInput(_message.Message):
    __slots__ = ["problem_id", "version"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DescribeCheckerOutput(_message.Message):
    __slots__ = ["checker"]
    CHECKER_FIELD_NUMBER: _ClassVar[int]
    checker: _checker_pb2.Checker
    def __init__(self, checker: _Optional[_Union[_checker_pb2.Checker, _Mapping]] = ...) -> None: ...

class DescribeInteractorInput(_message.Message):
    __slots__ = ["problem_id", "version"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DescribeInteractorOutput(_message.Message):
    __slots__ = ["interactor"]
    INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    interactor: _interactor_pb2.Interactor
    def __init__(self, interactor: _Optional[_Union[_interactor_pb2.Interactor, _Mapping]] = ...) -> None: ...

class DescribeTestInput(_message.Message):
    __slots__ = ["problem_id", "test_id", "testset_id", "version"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    TEST_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    test_id: str
    testset_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., testset_id: _Optional[str] = ..., test_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DescribeTestOutput(_message.Message):
    __slots__ = ["test"]
    TEST_FIELD_NUMBER: _ClassVar[int]
    test: _testing_test_pb2.Test
    def __init__(self, test: _Optional[_Union[_testing_test_pb2.Test, _Mapping]] = ...) -> None: ...

class DescribeTestingConfigInput(_message.Message):
    __slots__ = ["problem_id", "version"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DescribeTestingConfigOutput(_message.Message):
    __slots__ = ["config"]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: _testing_config_pb2.TestingConfig
    def __init__(self, config: _Optional[_Union[_testing_config_pb2.TestingConfig, _Mapping]] = ...) -> None: ...

class DescribeTestsetInput(_message.Message):
    __slots__ = ["problem_id", "testset_id", "version"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    testset_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., testset_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DescribeTestsetOutput(_message.Message):
    __slots__ = ["testset"]
    TESTSET_FIELD_NUMBER: _ClassVar[int]
    testset: _testing_testset_pb2.Testset
    def __init__(self, testset: _Optional[_Union[_testing_testset_pb2.Testset, _Mapping]] = ...) -> None: ...

class ListExamplesInput(_message.Message):
    __slots__ = ["problem_id", "version"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class ListExamplesOutput(_message.Message):
    __slots__ = ["examples"]
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    examples: _containers.RepeatedCompositeFieldContainer[_testing_test_pb2.Test]
    def __init__(self, examples: _Optional[_Iterable[_Union[_testing_test_pb2.Test, _Mapping]]] = ...) -> None: ...

class ListTestsInput(_message.Message):
    __slots__ = ["problem_id", "testset_id", "version"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    testset_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., testset_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class ListTestsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_testing_test_pb2.Test]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_testing_test_pb2.Test, _Mapping]]] = ...) -> None: ...

class ListTestsetsInput(_message.Message):
    __slots__ = ["problem_id", "version"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class ListTestsetsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_testing_testset_pb2.Testset]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_testing_testset_pb2.Testset, _Mapping]]] = ...) -> None: ...

class UpdateCheckerInput(_message.Message):
    __slots__ = ["checker", "problem_id"]
    CHECKER_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    checker: _checker_pb2.Checker
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ..., checker: _Optional[_Union[_checker_pb2.Checker, _Mapping]] = ...) -> None: ...

class UpdateCheckerOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateInteractorInput(_message.Message):
    __slots__ = ["interactor", "problem_id"]
    INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    interactor: _interactor_pb2.Interactor
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ..., interactor: _Optional[_Union[_interactor_pb2.Interactor, _Mapping]] = ...) -> None: ...

class UpdateInteractorOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateTestInput(_message.Message):
    __slots__ = ["problem_id", "test", "test_id", "testset_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    TEST_FIELD_NUMBER: _ClassVar[int]
    TEST_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    test: _testing_test_pb2.Test
    test_id: str
    testset_id: str
    def __init__(self, problem_id: _Optional[str] = ..., testset_id: _Optional[str] = ..., test_id: _Optional[str] = ..., test: _Optional[_Union[_testing_test_pb2.Test, _Mapping]] = ...) -> None: ...

class UpdateTestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateTestingConfigInput(_message.Message):
    __slots__ = ["config", "problem_id"]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    config: _testing_config_pb2.TestingConfig
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ..., config: _Optional[_Union[_testing_config_pb2.TestingConfig, _Mapping]] = ...) -> None: ...

class UpdateTestingConfigOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateTestsetInput(_message.Message):
    __slots__ = ["problem_id", "testset", "testset_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    testset: _testing_testset_pb2.Testset
    testset_id: str
    def __init__(self, problem_id: _Optional[str] = ..., testset_id: _Optional[str] = ..., testset: _Optional[_Union[_testing_testset_pb2.Testset, _Mapping]] = ...) -> None: ...

class UpdateTestsetOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/linked_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.community import linked_account_pb2 as eolymp_dot_community_dot_linked__account__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-eolymp/community/linked_account_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a%eolymp/community/linked_account.proto\x1a!eolymp/wellknown/expression.proto\"-\n\x1a\x44\x65scribeLinkedAccountInput\x12\x0f\n\x07link_id\x18\x01 \x01(\t\"L\n\x1b\x44\x65scribeLinkedAccountOutput\x12-\n\x04link\x18\x01 \x01(\x0b\x32\x1f.eolymp.community.LinkedAccount\"\xe0\x01\n\x17ListLinkedAccountsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x41\n\x07\x66ilters\x18( \x01(\x0b\x32\x30.eolymp.community.ListLinkedAccountsInput.Filter\x1a\x64\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Y\n\x18ListLinkedAccountsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.community.LinkedAccount\"+\n\x18\x44\x65leteLinkedAccountInput\x12\x0f\n\x07link_id\x18\x01 \x01(\t\"\x1b\n\x19\x44\x65leteLinkedAccountOutput2\xfb\x03\n\x14LinkedAccountService\x12\xa7\x01\n\x15\x44\x65scribeLinkedAccount\x12,.eolymp.community.DescribeLinkedAccountInput\x1a-.eolymp.community.DescribeLinkedAccountOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c\x12\x1a/linked-accounts/{link_id}\x12\x94\x01\n\x12ListLinkedAccounts\x12).eolymp.community.ListLinkedAccountsInput\x1a*.eolymp.community.ListLinkedAccountsOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x12\x12\x10/linked-accounts\x12\xa1\x01\n\x13\x44\x65leteLinkedAccount\x12*.eolymp.community.DeleteLinkedAccountInput\x1a+.eolymp.community.DeleteLinkedAccountOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c*\x1a/linked-accounts/{link_id}B5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.linked_account_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _LINKEDACCOUNTSERVICE.methods_by_name['DescribeLinkedAccount']._options = None
  _LINKEDACCOUNTSERVICE.methods_by_name['DescribeLinkedAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034\022\032/linked-accounts/{link_id}'
  _LINKEDACCOUNTSERVICE.methods_by_name['ListLinkedAccounts']._options = None
  _LINKEDACCOUNTSERVICE.methods_by_name['ListLinkedAccounts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\022\022\020/linked-accounts'
  _LINKEDACCOUNTSERVICE.methods_by_name['DeleteLinkedAccount']._options = None
  _LINKEDACCOUNTSERVICE.methods_by_name['DeleteLinkedAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034*\032/linked-accounts/{link_id}'
  _DESCRIBELINKEDACCOUNTINPUT._serialized_start=208
  _DESCRIBELINKEDACCOUNTINPUT._serialized_end=253
  _DESCRIBELINKEDACCOUNTOUTPUT._serialized_start=255
  _DESCRIBELINKEDACCOUNTOUTPUT._serialized_end=331
  _LISTLINKEDACCOUNTSINPUT._serialized_start=334
  _LISTLINKEDACCOUNTSINPUT._serialized_end=558
  _LISTLINKEDACCOUNTSINPUT_FILTER._serialized_start=458
  _LISTLINKEDACCOUNTSINPUT_FILTER._serialized_end=558
  _LISTLINKEDACCOUNTSOUTPUT._serialized_start=560
  _LISTLINKEDACCOUNTSOUTPUT._serialized_end=649
  _DELETELINKEDACCOUNTINPUT._serialized_start=651
  _DELETELINKEDACCOUNTINPUT._serialized_end=694
  _DELETELINKEDACCOUNTOUTPUT._serialized_start=696
  _DELETELINKEDACCOUNTOUTPUT._serialized_end=723
  _LINKEDACCOUNTSERVICE._serialized_start=726
  _LINKEDACCOUNTSERVICE._serialized_end=1233
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import assignment_item_v2_pb2 as _assignment_item_v2_pb2
from eolymp.course import assignment_v2_pb2 as _assignment_v2_pb2
from eolymp.course import module_item_pb2 as _module_item_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAssignmentV2Input(_message.Message):
    __slots__ = ["complete_before", "duration", "module_id", "start_after"]
    COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    START_AFTER_FIELD_NUMBER: _ClassVar[int]
    complete_before: _timestamp_pb2.Timestamp
    duration: int
    module_id: str
    start_after: _timestamp_pb2.Timestamp
    def __init__(self, module_id: _Optional[str] = ..., start_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ...) -> None: ...

class CreateAssignmentV2Output(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteAssignmentV2Input(_message.Message):
    __slots__ = ["module_id"]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    def __init__(self, module_id: _Optional[str] = ...) -> None: ...

class DeleteAssignmentV2Output(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeAssignmentItemV2Input(_message.Message):
    __slots__ = ["extra", "item_id", "module_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_module_item_pb2.ModuleItem.Extra]
    item_id: str
    module_id: str
    def __init__(self, module_id: _Optional[str] = ..., item_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_module_item_pb2.ModuleItem.Extra, str]]] = ...) -> None: ...

class DescribeAssignmentItemV2Output(_message.Message):
    __slots__ = ["item"]
    ITEM_FIELD_NUMBER: _ClassVar[int]
    item: _assignment_item_v2_pb2.AssignmentItemV2
    def __init__(self, item: _Optional[_Union[_assignment_item_v2_pb2.AssignmentItemV2, _Mapping]] = ...) -> None: ...

class ListAssignmentItemsV2Input(_message.Message):
    __slots__ = ["module_id"]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    def __init__(self, module_id: _Optional[str] = ...) -> None: ...

class ListAssignmentItemsV2Output(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_assignment_item_v2_pb2.AssignmentItemV2]
    def __init__(self, items: _Optional[_Iterable[_Union[_assignment_item_v2_pb2.AssignmentItemV2, _Mapping]]] = ...) -> None: ...

class ListAssignmentsV2Input(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListAssignmentsV2Output(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_assignment_v2_pb2.AssignmentV2]
    def __init__(self, items: _Optional[_Iterable[_Union[_assignment_v2_pb2.AssignmentV2, _Mapping]]] = ...) -> None: ...

class ResetAssignmentItemV2Input(_message.Message):
    __slots__ = ["item_id", "module_id"]
    ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    item_id: str
    module_id: str
    def __init__(self, module_id: _Optional[str] = ..., item_id: _Optional[str] = ...) -> None: ...

class ResetAssignmentItemV2Output(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StartAssignmentV2Input(_message.Message):
    __slots__ = ["module_id"]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    def __init__(self, module_id: _Optional[str] = ...) -> None: ...

class StartAssignmentV2Output(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateAssignmentItemV2Input(_message.Message):
    __slots__ = ["item", "item_id", "module_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateAssignmentItemV2Input.Patch
    EXCUSED: UpdateAssignmentItemV2Input.Patch
    GRADE_OVERRIDE: UpdateAssignmentItemV2Input.Patch
    GRADE_OVERRIDE_RESET: UpdateAssignmentItemV2Input.Patch
    ITEM_FIELD_NUMBER: _ClassVar[int]
    ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    item: _assignment_item_v2_pb2.AssignmentItemV2
    item_id: str
    module_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateAssignmentItemV2Input.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateAssignmentItemV2Input.Patch, str]]] = ..., module_id: _Optional[str] = ..., item_id: _Optional[str] = ..., item: _Optional[_Union[_assignment_item_v2_pb2.AssignmentItemV2, _Mapping]] = ...) -> None: ...

class UpdateAssignmentItemV2Output(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Attribute(_message.Message):
    __slots__ = ["choices", "constraints", "country", "description", "help", "hidden", "index", "key", "label", "max", "min", "readonly", "regexp", "required", "type", "visibility"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Description(_message.Message):
        __slots__ = ["choices", "help", "label", "locale"]
        CHOICES_FIELD_NUMBER: _ClassVar[int]
        HELP_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        choices: _containers.RepeatedScalarFieldContainer[str]
        help: str
        label: str
        locale: str
        def __init__(self, locale: _Optional[str] = ..., label: _Optional[str] = ..., help: _Optional[str] = ..., choices: _Optional[_Iterable[str]] = ...) -> None: ...
    class Value(_message.Message):
        __slots__ = ["attribute_key", "attribute_type", "number", "string"]
        ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
        ATTRIBUTE_TYPE_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        STRING_FIELD_NUMBER: _ClassVar[int]
        attribute_key: str
        attribute_type: Attribute.Type
        number: int
        string: str
        def __init__(self, attribute_key: _Optional[str] = ..., attribute_type: _Optional[_Union[Attribute.Type, str]] = ..., string: _Optional[str] = ..., number: _Optional[int] = ...) -> None: ...
    CHECKBOX: Attribute.Type
    CHOICE: Attribute.Type
    CHOICES_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    COUNTRY: Attribute.Type
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    DATE: Attribute.Type
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EMAIL: Attribute.Type
    FILE: Attribute.Type
    HELP_FIELD_NUMBER: _ClassVar[int]
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    IMAGE: Attribute.Type
    INDEX_FIELD_NUMBER: _ClassVar[int]
    INSTITUTION: Attribute.Type
    INTERNAL: Attribute.Visibility
    KEY_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    MAX_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    NUMBER: Attribute.Type
    PRIVATE: Attribute.Visibility
    PUBLIC: Attribute.Visibility
    READONLY_FIELD_NUMBER: _ClassVar[int]
    REGEXP_FIELD_NUMBER: _ClassVar[int]
    REGION: Attribute.Type
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    STRING: Attribute.Type
    TEXT: Attribute.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN: Attribute.Type
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    choices: _containers.RepeatedScalarFieldContainer[str]
    constraints: _containers.RepeatedScalarFieldContainer[str]
    country: str
    description: _containers.RepeatedCompositeFieldContainer[Attribute.Description]
    help: str
    hidden: bool
    index: int
    key: str
    label: str
    max: int
    min: int
    readonly: bool
    regexp: str
    required: bool
    type: Attribute.Type
    visibility: Attribute.Visibility
    def __init__(self, key: _Optional[str] = ..., label: _Optional[str] = ..., help: _Optional[str] = ..., description: _Optional[_Iterable[_Union[Attribute.Description, _Mapping]]] = ..., type: _Optional[_Union[Attribute.Type, str]] = ..., index: _Optional[int] = ..., required: bool = ..., readonly: bool = ..., hidden: bool = ..., visibility: _Optional[_Union[Attribute.Visibility, str]] = ..., regexp: _Optional[str] = ..., min: _Optional[int] = ..., max: _Optional[int] = ..., choices: _Optional[_Iterable[str]] = ..., country: _Optional[str] = ..., constraints: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PostType(_message.Message):
    __slots__ = ["hidden", "id", "name", "order", "variants"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Variant(_message.Message):
        __slots__ = ["locale", "name"]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        locale: str
        name: str
        def __init__(self, locale: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EXTRA: PostType.Extra
    VARIANTS: PostType.Extra
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    hidden: bool
    id: str
    name: str
    order: int
    variants: _containers.RepeatedCompositeFieldContainer[PostType.Variant]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., hidden: bool = ..., order: _Optional[int] = ..., variants: _Optional[_Iterable[_Union[PostType.Variant, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/module_item.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/course/module_item.proto\x12\reolymp.course\x1a\x18\x65olymp/ecm/content.proto\"\xe6\x03\n\nModuleItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x64raft\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\r\n\x05index\x18\x0b \x01(\r\x12\r\n\x05\x64\x65pth\x18\x0c \x01(\r\x12\x32\n\x07grading\x18\x1e \x01(\x0b\x32!.eolymp.course.ModuleItem.Grading\x12\x36\n\x08\x64ocument\x18\x64 \x01(\x0b\x32\".eolymp.course.ModuleItem.DocumentH\x00\x12.\n\x04task\x18\x65 \x01(\x0b\x32\x1e.eolymp.course.ModuleItem.TaskH\x00\x1a\x30\n\x08\x44ocument\x12$\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a\x1a\n\x04Task\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x1a,\n\x07Grading\x12\x11\n\tmax_score\x18\x01 \x01(\r\x12\x0e\n\x06weight\x18\x02 \x01(\x02\"N\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\x11\n\rCONTENT_VALUE\x10\x02\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x03\x42\t\n\x07\x63ontentB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_item_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MODULEITEM._serialized_start=77
  _MODULEITEM._serialized_end=563
  _MODULEITEM_DOCUMENT._serialized_start=350
  _MODULEITEM_DOCUMENT._serialized_end=398
  _MODULEITEM_TASK._serialized_start=400
  _MODULEITEM_TASK._serialized_end=426
  _MODULEITEM_GRADING._serialized_start=428
  _MODULEITEM_GRADING._serialized_end=472
  _MODULEITEM_EXTRA._serialized_start=474
  _MODULEITEM_EXTRA._serialized_end=552
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.atlas import suggestion_pb2 as _suggestion_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSuggestionInput(_message.Message):
    __slots__ = ["problem_id", "suggestion"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    suggestion: _suggestion_pb2.Suggestion
    def __init__(self, problem_id: _Optional[str] = ..., suggestion: _Optional[_Union[_suggestion_pb2.Suggestion, _Mapping]] = ...) -> None: ...

class CreateSuggestionOutput(_message.Message):
    __slots__ = ["suggestion_id"]
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    suggestion_id: str
    def __init__(self, suggestion_id: _Optional[str] = ...) -> None: ...

class DeleteSuggestionInput(_message.Message):
    __slots__ = ["problem_id", "suggestion_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    suggestion_id: str
    def __init__(self, problem_id: _Optional[str] = ..., suggestion_id: _Optional[str] = ...) -> None: ...

class DeleteSuggestionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeSuggestionInput(_message.Message):
    __slots__ = ["problem_id", "suggestion_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    suggestion_id: str
    def __init__(self, problem_id: _Optional[str] = ..., suggestion_id: _Optional[str] = ...) -> None: ...

class DescribeSuggestionOutput(_message.Message):
    __slots__ = ["suggestion"]
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    suggestion: _suggestion_pb2.Suggestion
    def __init__(self, suggestion: _Optional[_Union[_suggestion_pb2.Suggestion, _Mapping]] = ...) -> None: ...

class ListSuggestionsInput(_message.Message):
    __slots__ = ["filters", "offset", "problem_id", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "member_id", "status"]
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListSuggestionsInput.Filter
    offset: int
    problem_id: str
    size: int
    def __init__(self, problem_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListSuggestionsInput.Filter, _Mapping]] = ...) -> None: ...

class ListSuggestionsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_suggestion_pb2.Suggestion]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_suggestion_pb2.Suggestion, _Mapping]]] = ...) -> None: ...

class ResubmitSuggestionInput(_message.Message):
    __slots__ = ["problem_id", "suggestion_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    suggestion_id: str
    def __init__(self, problem_id: _Optional[str] = ..., suggestion_id: _Optional[str] = ...) -> None: ...

class ResubmitSuggestionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ReviewSuggestionInput(_message.Message):
    __slots__ = ["comment", "problem_id", "status", "suggestion_id"]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    comment: _content_pb2.Content
    problem_id: str
    status: _suggestion_pb2.Suggestion.Status
    suggestion_id: str
    def __init__(self, problem_id: _Optional[str] = ..., suggestion_id: _Optional[str] = ..., status: _Optional[_Union[_suggestion_pb2.Suggestion.Status, str]] = ..., comment: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class ReviewSuggestionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateSuggestionInput(_message.Message):
    __slots__ = ["problem_id", "suggestion", "suggestion_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    suggestion: _suggestion_pb2.Suggestion
    suggestion_id: str
    def __init__(self, problem_id: _Optional[str] = ..., suggestion_id: _Optional[str] = ..., suggestion: _Optional[_Union[_suggestion_pb2.Suggestion, _Mapping]] = ...) -> None: ...

class UpdateSuggestionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...
